@@ -18,7 +18,8 @@ __all__ = [
     'int32', 'n_int32', 'b_int32', 'l_int32', 'uint32', 'n_uint32', 'b_uint32', 'l_uint32',
     'int64', 'n_int64', 'b_int64', 'l_int64', 'uint64', 'n_uint64', 'b_uint64', 'l_uint64',
     'int_field', 'float_field', 'str_type', 'str_type_factory', 'str_field', 'buffer_field', 'list_field',
-    'bytearray_field', 'be_int_field', 'le_int_field', 'bytes_ref', 'total_size', 'after_ref', 'member_func_ref'
+    'bytearray_field', 'be_int_field', 'le_int_field', 'bytes_ref', 'total_size', 'after_ref', 'member_func_ref',
+    'le_uint_field', 'be_uint_field'
 ]
 JUSTIFY = ('left', 'right')
 
@@ -278,11 +279,21 @@ def int_field(endian='native', sign='signed',
     return builder.create()
 
 
+def be_uint_field(*args, **kwargs):
+    kwargs.update(sign='unsigned')
+    return be_int_field(*args, **kwargs)
+
+
 def be_int_field(*args, **kwargs):
     kwargs.update(dict(endian='big'))
     return int_field(*args, **kwargs)
 
 
+def le_uint_field(*args, **kwargs):
+    kwargs.update(sign='unsigned')
+    return le_int_field(*args, **kwargs)
+
+
 def le_int_field(*args, **kwargs):
     kwargs.update(dict(endian='little'))
     return int_field(*args, **kwargs)
